import { defineStore } from 'pinia'
import { ref, watch } from 'vue'

export const useThemeStore = defineStore('theme', () => {
  const isDark = ref(localStorage.getItem('theme') === 'dark')
  
  function toggleTheme() {
    isDark.value = !isDark.value
  }

  // 监听isDark值的变化
  watch(isDark, (newValue) => {
    localStorage.setItem('theme', newValue ? 'dark' : 'light')
    document.documentElement.setAttribute('data-theme', newValue ? 'dark' : 'light')
  })

  // 初始化主题
  document.documentElement.setAttribute('data-theme', isDark.value ? 'dark' : 'light')

  return { isDark, toggleTheme }
})